/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.2 Baustellensimulation
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.simbaustelle.migration.modell.geo;

import de.bsvrz.ibv.simbaustelle.migration.modell.SystemObjekt;
import de.bsvrz.ibv.simbaustelle.migration.modell.SystemObjektTyp;
import de.bsvrz.ibv.simbaustelle.migration.modell.geo.objekte.LinieXYImpl;
import de.bsvrz.ibv.simbaustelle.migration.modell.geo.objekte.PunktLiegtAufLinienObjektmpl;
import de.bsvrz.ibv.simbaustelle.migration.modell.geo.objekte.PunktXYImpl;

/**
 * Definition der Typen, die von {@link GeoModellFactory} angelegt werden
 * können.
 *
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public enum GeoModellTypen implements SystemObjektTyp {

	/** Ein Punkt. */
	PUNKT_XY("typ.punktXY", PunktXYImpl.class),

	/** Eine Linie. */
	LINIE_XY("typ.linieXY", LinieXYImpl.class),

	/** Eine Linie. */
	PUNKT_LIEGT_AUF_LINIEN_OBJEKT("typ.punktLiegtAufLinienObjekt",
			PunktLiegtAufLinienObjektmpl.class);

	/** PID des Objekttyps im Datenverteiler. */
	private final String pid;

	/** Klasse des Systemobjekts im Modell. */
	private final Class<? extends SystemObjekt> klasse;

	/**
	 * Privater Konstruktor.
	 *
	 * @param pid
	 *            Die PID des Typs
	 * @param klasse
	 *            Die Klasse des Modellobjekts
	 */
	GeoModellTypen(final String pid,
			final Class<? extends SystemObjekt> klasse) {
		this.pid = pid;
		this.klasse = klasse;
	}

	@Override
	public Class<? extends SystemObjekt> getKlasse() {
		return klasse;
	}

	@Override
	public String getPid() {
		return pid;
	}
}
